summaryrefslogtreecommitdiff
path: root/cesar/bsu/bsu.h
diff options
context:
space:
mode:
authorNélio Laranjeiro2012-09-05 16:45:01 +0200
committerNélio Laranjeiro2012-12-12 15:05:21 +0100
commit262b802bb1353361e83f878c6e02f455e2deaa01 (patch)
tree80b9b83607dca518c69c2ecc5495a260ff7ee65b /cesar/bsu/bsu.h
parent513ddabb1dd641745c596cc90ec33d21ccf02233 (diff)
cesar/bsu: add a context to bsu_init_beacon_cb, refs #3386
Diffstat (limited to 'cesar/bsu/bsu.h')
-rw-r--r--cesar/bsu/bsu.h7
1 files changed, 4 insertions, 3 deletions
diff --git a/cesar/bsu/bsu.h b/cesar/bsu/bsu.h
index 394b9f43d2..8885684e62 100644
--- a/cesar/bsu/bsu.h
+++ b/cesar/bsu/bsu.h
@@ -65,11 +65,12 @@ bsu_init (bsu_aclf_t *aclf, mac_config_t *mac_config, phy_t *phy,
/**
* Initialise the beacon callback to send to upper layer.
* \param cb the function to call.
* \param ul the upper layer user data.
*/
void
-bsu_init_beacon_cb (bsu_beacon_processed_t cb, void *cb_ud);
+bsu_init_beacon_cb (bsu_t *ctx, bsu_beacon_processed_t cb, void *cb_ud);
/**
* Uninitialise the module.
@@ -65,11 +65,12 @@ bsu_init (bsu_aclf_t *aclf, mac_config_t *mac_config, phy_t *phy,
/**
* Initialise the beacon callback to send to upper layer.
- * \param cb the function to call.
- * \param ul the upper layer user data.
+ * \param ctx the module context
+ * \param cb the function to call
+ * \param ul the upper layer user data
*/
void